# Changelog

## 1.1.0 (2024-08-09)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/squack-io/flux-python/compare/v1.0.0...v1.1.0)

### Features

* **api:** my cool feature ([#28](https://github.com/squack-io/flux-python/issues/28)) ([d2deb2e](https://github.com/squack-io/flux-python/commit/d2deb2ee973e97e838bced30983752d33dab5394))

## 1.0.0 (2024-08-09)

Full Changelog: [v0.1.0-alpha.6...v1.0.0](https://github.com/squack-io/flux-python/compare/v0.1.0-alpha.6...v1.0.0)

### Chores

* update SDK settings ([#25](https://github.com/squack-io/flux-python/issues/25)) ([fde154b](https://github.com/squack-io/flux-python/commit/fde154b29586766163eb64eb4daa110487dd0e7a))

## 0.1.0-alpha.6 (2024-08-09)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/squack-io/flux-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** update via SDK Studio ([#22](https://github.com/squack-io/flux-python/issues/22)) ([3742880](https://github.com/squack-io/flux-python/commit/3742880089c143d36cc3e85a9ca80ddd085c2686))

## 0.1.0-alpha.5 (2024-08-08)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/squack-io/flux-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** update via SDK Studio ([#19](https://github.com/squack-io/flux-python/issues/19)) ([b2617bc](https://github.com/squack-io/flux-python/commit/b2617bcf2785bddf51185b1cf77b938121c0e2bb))

## 0.1.0-alpha.4 (2024-08-08)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/squack-io/flux-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([2425a4b](https://github.com/squack-io/flux-python/commit/2425a4b1289bb936cc18dcc52bc13fab221b9750))
* **api:** update via SDK Studio ([#4](https://github.com/squack-io/flux-python/issues/4)) ([38f9ce9](https://github.com/squack-io/flux-python/commit/38f9ce982e7e1a0cbcd114356df7410dab7347b4))
* **api:** update via SDK Studio ([#6](https://github.com/squack-io/flux-python/issues/6)) ([123b81f](https://github.com/squack-io/flux-python/commit/123b81fa132381c4654e04a8c0396e6838477360))


### Chores

* go live ([#1](https://github.com/squack-io/flux-python/issues/1)) ([73a3b1e](https://github.com/squack-io/flux-python/commit/73a3b1e5dca528c77bc459943b40a58c842b51d9))
* **internal:** version bump ([#9](https://github.com/squack-io/flux-python/issues/9)) ([e677f47](https://github.com/squack-io/flux-python/commit/e677f4748dd0fc80f3d82d01b85ee426ebd5c888))
* update SDK settings ([#3](https://github.com/squack-io/flux-python/issues/3)) ([337b583](https://github.com/squack-io/flux-python/commit/337b583a9cd96ef736cde9666f5ec9e60e475a0a))

## 0.1.0-alpha.3 (2024-08-08)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/squack-io/flux-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Chores

* **internal:** version bump ([#9](https://github.com/squack-io/flux-python/issues/9)) ([e677f47](https://github.com/squack-io/flux-python/commit/e677f4748dd0fc80f3d82d01b85ee426ebd5c888))

## 0.1.0-alpha.2 (2024-08-08)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/squack-io/flux-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([#6](https://github.com/squack-io/flux-python/issues/6)) ([123b81f](https://github.com/squack-io/flux-python/commit/123b81fa132381c4654e04a8c0396e6838477360))

## 0.1.0-alpha.1 (2024-08-08)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/squack-io/flux-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([2425a4b](https://github.com/squack-io/flux-python/commit/2425a4b1289bb936cc18dcc52bc13fab221b9750))
* **api:** update via SDK Studio ([#4](https://github.com/squack-io/flux-python/issues/4)) ([38f9ce9](https://github.com/squack-io/flux-python/commit/38f9ce982e7e1a0cbcd114356df7410dab7347b4))


### Chores

* go live ([#1](https://github.com/squack-io/flux-python/issues/1)) ([73a3b1e](https://github.com/squack-io/flux-python/commit/73a3b1e5dca528c77bc459943b40a58c842b51d9))
* update SDK settings ([#3](https://github.com/squack-io/flux-python/issues/3)) ([337b583](https://github.com/squack-io/flux-python/commit/337b583a9cd96ef736cde9666f5ec9e60e475a0a))
